@@ -23,11 +23,12 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
-	"github.com/apache/answer/internal/service/siteinfo_common"
 	"math"
 	"strings"
 	"time"
 
+	"github.com/apache/answer/internal/service/siteinfo_common"
+
 	"github.com/apache/answer/internal/base/constant"
 	"github.com/apache/answer/internal/base/data"
 	"github.com/apache/answer/internal/base/handler"
@@ -63,6 +64,7 @@ type QuestionRepo interface {
 	GetRecommendQuestionPageByTags(ctx context.Context, userID string, tagIDs, followedQuestionIDs []string, page, pageSize int) (questionList []*entity.Question, total int64, err error)
 	UpdateQuestionStatus(ctx context.Context, questionID string, status int) (err error)
 	UpdateQuestionStatusWithOutUpdateTime(ctx context.Context, question *entity.Question) (err error)
+	DeletePermanentlyQuestions(ctx context.Context) (err error)
 	RecoverQuestion(ctx context.Context, questionID string) (err error)
 	UpdateQuestionOperation(ctx context.Context, question *entity.Question) (err error)
 	GetQuestionsByTitle(ctx context.Context, title string, pageSize int) (questionList []*entity.Question, err error)
@@ -383,6 +385,7 @@ func (qs *QuestionCommon) FormatQuestionsPage(
 			LastAnswerID:     questionInfo.LastAnswerID,
 			Pin:              questionInfo.Pin,
 			Show:             questionInfo.Show,
+			Operator:         &schema.QuestionPageRespOperator{ID: questionInfo.UserID},
 		}
 
 		questionIDs = append(questionIDs, questionInfo.ID)
@@ -407,19 +410,18 @@ func (qs *QuestionCommon) FormatQuestionsPage(
 			}
 		}
 
-		// if order condition is newest or nobody edited or nobody answered, only show question author
-		if orderCond == schema.QuestionOrderCondNewest || (!haveEdited && !haveAnswered) {
-			t.OperationType = schema.QuestionPageRespOperationTypeAsked
-			t.OperatedAt = questionInfo.CreatedAt.Unix()
-			t.Operator = &schema.QuestionPageRespOperator{ID: questionInfo.UserID}
-		} else {
-			// if no one
+		// The default operation is to ask questions
+		t.OperationType = schema.QuestionPageRespOperationTypeAsked
+		t.OperatedAt = questionInfo.CreatedAt.Unix()
+		t.Operator = &schema.QuestionPageRespOperator{ID: questionInfo.UserID}
+
+		// If the order is active, the last operation time is the last edit or answer time if it exists
+		if orderCond == schema.QuestionOrderCondActive {
 			if haveEdited {
 				t.OperationType = schema.QuestionPageRespOperationTypeModified
 				t.OperatedAt = questionInfo.UpdatedAt.Unix()
 				t.Operator = &schema.QuestionPageRespOperator{ID: questionInfo.LastEditUserID}
 			}
-
 			if haveAnswered {
 				if t.LastAnsweredAt.Unix() > t.OperatedAt {
 					t.OperationType = schema.QuestionPageRespOperationTypeAnswered
@@ -428,6 +430,7 @@ func (qs *QuestionCommon) FormatQuestionsPage(
 				}
 			}
 		}
+
 		formattedQuestions = append(formattedQuestions, t)
 	}
 
@@ -454,9 +457,9 @@ func (qs *QuestionCommon) FormatQuestionsPage(
 				item.Operator.Username = userInfo.Username
 				item.Operator.Rank = userInfo.Rank
 				item.Operator.Status = userInfo.Status
+				item.Operator.Avatar = userInfo.Avatar
 			}
 		}
-
 	}
 	return formattedQuestions, nil
 }
@@ -707,7 +710,7 @@ func (qs *QuestionCommon) UpdateQuestionLink(ctx context.Context, questionID, an
 		return parsedText, err
 	}
 	// Update the number of question links that have been removed
-	linkedQuestionIDs, err := qs.questionRepo.GetLinkedQuestionIDs(ctx, questionID, entity.QuestionLinkStatusDeleted)
+	linkedQuestionIDs, err := qs.questionRepo.GetLinkedQuestionIDs(ctx, uid.DeShortID(questionID), entity.QuestionLinkStatusDeleted)
 	if err != nil {
 		log.Errorf("get linked question ids error %v", err)
 	} else {
