@@ -190,8 +190,8 @@ const Users: FC = () => {
   return (
     <>
       <h3 className="mb-4">{t('title')}</h3>
-      <div className="d-flex flex-wrap justify-content-between align-items-center mb-3">
-        <Stack direction="horizontal" gap={3}>
+      <div className="d-flex flex-wrap justify-content-between align-items-center">
+        <Stack direction="horizontal" gap={3} className="mb-3">
           <QueryGroup
             data={UserFilterKeys}
             currentSort={curFilter}
@@ -223,7 +223,7 @@ const Users: FC = () => {
           onChange={handleFilter}
           placeholder={t('filter.placeholder')}
           style={{ width: '12.25rem' }}
-          className="mt-3 mt-sm-0"
+          className="mb-3"
         />
       </div>
       <Table responsive="md">
